@@ -3,11 +3,12 @@ package Test::Compile;
 use warnings;
 use strict;
 use Test::Builder;
+use Devel::CheckOS qw(os_is os_isnt);
 use File::Spec;
 use UNIVERSAL::require;
 
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 
 my $Test = Test::Builder->new;
@@ -17,7 +18,11 @@ sub import {
     my $self = shift;
     my $caller = caller;
 
-   for my $func ( qw( pm_file_ok all_pm_files all_pm_files_ok ) ) {
+   for my $func (qw(
+       pm_file_ok pl_file_ok all_pm_files all_pl_files all_pm_files_ok
+       all_pl_files_ok
+       )) {
+
         no strict 'refs';
         *{$caller."::".$func} = \&$func;
     }
@@ -57,6 +62,40 @@ sub pm_file_ok {
 }
 
 
+sub pl_file_ok {
+    my $file = shift;
+    my $name = @_ ? shift : "Compile test for $file";
+
+    SKIP: {
+
+        # Exclude VMS because $^X doesn't work
+        # In general perl is a symlink to perlx.y.z
+        # but VMS stores symlinks differently...
+        unless (os_is('OSFeatures::POSIXShellRedirection') and os_isnt('VMS')) {
+            skip('Test not compatible with your OS');
+            return;
+        }
+
+        unless (-f $file) {
+            $Test->ok(0, $name);
+            $Test->diag("$file does not exist");
+            return;
+        }
+
+        my $out = `$^X -cw $file 2>&1`;
+
+        if ($?) {
+            $Test->ok(0, 'Script does not compile');
+            $Test->diag($out);
+            return;
+        } else {
+            $Test->ok(1);
+            return 1;
+        }
+    }
+}
+
+
 sub all_pm_files_ok {
     my @files = @_ ? @_ : all_pm_files();
 
@@ -70,13 +109,26 @@ sub all_pm_files_ok {
 }
 
 
+sub all_pl_files_ok {
+    my @files = @_ ? @_ : all_pl_files();
+
+    $Test->plan(tests => scalar @files);
+
+    my $ok = 1;
+    for (@files) {
+        pl_file_ok($_) or undef $ok;
+    }
+    $ok;
+}
+
+
 sub all_pm_files {
-    my @queue = @_ ? @_ : _starting_points();
+    my @queue = @_ ? @_ : _pm_starting_points();
     my @pm;
 
-    while ( @queue ) {
+    while (@queue) {
         my $file = shift @queue;
-        if ( -d $file ) {
+        if (-d $file) {
             local *DH;
             opendir DH, $file or next;
             my @newfiles = readdir DH;
@@ -98,28 +150,70 @@ sub all_pm_files {
             push @pm, $file if $file =~ /\.pm$/;
         }
     }
-    return @pm;
+    @pm;
 }
 
 
-sub _starting_points {
+sub all_pl_files {
+    my @queue = @_ ? @_ : _pl_starting_points();
+    my @pl;
+
+    while (@queue) {
+        my $file = shift @queue;
+        if (-d $file) {
+            local *DH;
+            opendir DH, $file or next;
+            my @newfiles = readdir DH;
+            closedir DH;
+
+            @newfiles = File::Spec->no_upwards(@newfiles);
+            @newfiles = grep { $_ ne "CVS" && $_ ne ".svn" } @newfiles;
+
+            for my $newfile (@newfiles) {
+                my $filename = File::Spec->catfile($file, $newfile);
+                if (-f $filename) {
+                    push @queue, $filename;
+                } else {
+                    push @queue, File::Spec->catdir($file, $newfile);
+                }
+            }
+        }
+        if (-f $file) {
+            # Only accept files with no extension or extension .pl
+            push @pl, $file if $file =~ /(?:^[^.]+$|\.pl$)/;
+        }
+    }
+    @pl;
+}
+
+
+sub _pm_starting_points {
     return 'blib' if -e 'blib';
     return 'lib';
 }
 
 
+sub _pl_starting_points {
+    return 'script' if -e 'script';
+    return 'bin' if -e 'bin';
+}
+
+
 1;
 
+
 __END__
 
+
+
 =head1 NAME
 
 Test::Compile - check whether Perl module files compile correctly
 
 =head1 SYNOPSIS
 
-C<Test::Compile> lets you check the validity of a Perl module file, and report
-its results in standard C<Test::Simple> fashion.
+C<Test::Compile> lets you check the validity of a Perl module file or Perl
+script file, and report its results in standard C<Test::Simple> fashion.
 
     BEGIN {
         use Test::Compile tests => $num_tests;
@@ -161,7 +255,7 @@ Or even (if you're running under L<Apache::Test>):
     my @pmdirs = qw(blib script);
     use File::Spec::Functions qw(catdir updir);
     all_pm_files_ok(
-        all_pm_files( map { catdir updir, $_ } @pmdirs )
+        all_pm_files(map { catdir updir, $_ } @pmdirs)
     );
 
 Why do the examples use C<BAIL_OUT()> instead of C<skip_all()>? Because
@@ -185,18 +279,32 @@ C<pm_file_ok()> will okay the test if the Perl module compiles correctly.
 When it fails, C<pm_file_ok()> will show any compilation errors as
 diagnostics.
 
-The optional second argument TESTNAME is the name of the test.  If it is
+The optional second argument TESTNAME is the name of the test. If it is
 omitted, C<pm_file_ok()> chooses a default test name "Compile test for
 FILENAME".
 
+=item pl_file_ok(FILENAME[, TESTNAME ])
+
+C<pl_file_ok()> will okay the test if the Perl script compiles correctly. You
+need to give the path to the script relative to this distribution's base
+directory. So if you put your scripts in a 'top-level' directory called script
+the argument would be script/filename
+
+When it fails, C<pl_file_ok()> will show any compilation errors as
+diagnostics.
+
+The optional second argument TESTNAME is the name of the test. If it is
+omitted, C<pl_file_ok()> chooses a default test name "Compile test for
+FILENAME".
+
 =item all_pm_files_ok([@files/@directories])
 
-Checks all the files in C<@files> for compilation.  It runs L<all_pm_files()>
+Checks all the files in C<@files> for compilation. It runs L<all_pm_files()>
 on each file/directory, and calls the C<plan()> function for you (one test for
 each function), so you can't have already called C<plan>.
 
 If C<@files> is empty or not passed, the function finds all Perl module files
-in the F<blib> directory if it exists, or the F<lib> directory if not.  A Perl
+in the F<blib> directory if it exists, or the F<lib> directory if not. A Perl
 module file is one that ends with F<.pm>.
 
 If you're testing a module, just make a F<t/00_compile.t>:
@@ -212,14 +320,43 @@ Returns true if all Perl module files are ok, or false if any fail.
 Or you could just let L<Module::Install::StandardTests> do all the work for
 you.
 
+=item all_pl_files_ok([@files])
+
+Checks all the files in C<@files> for compilation. It runs L<pl_file_ok()>
+on each file, and calls the C<plan()> function for you (one test for
+each file), so you can't have already called C<plan>.
+
+If C<@files> is empty or not passed, the function uses all_pl_files() to find
+scripts to test
+
+If you're testing a module, just make a F<t/00_compile_scripts.t>:
+
+    use Test::More;
+    eval "use Test::Compile 1.00";
+    plan skip_all => "Test::Compile 1.00 required for testing compilation"
+      if $@;
+    all_pl_files_ok();
+
+Returns true if all Perl module files are ok, or false if any fail.
+
 =item all_pm_files([@dirs])
 
 Returns a list of all the perl module files - that is, files ending in F<.pm>
 - in I<$dir> and in directories below. If no directories are passed, it
-defaults to F<blib> if F<blib> exists, or else F<lib> if not.  Skips any files
+defaults to F<blib> if F<blib> exists, or else F<lib> if not. Skips any files
 in CVS or .svn directories.
 
-The order of the files returned is machine-dependent.  If you want them
+The order of the files returned is machine-dependent. If you want them
+sorted, you'll have to sort them yourself.
+
+=item all_pl_files([@files/@dirs])
+
+Returns a list of all the perl script files - that is, files ending in F<.pl>
+or with no extension. Directory arguments are searched recursively . If
+arguments are passed, it defaults to F<script> if F<script> exists, or else
+F<bin> if F<bin> exists. Skips any files in CVS or .svn directories.
+
+The order of the files returned is machine-dependent. If you want them
 sorted, you'll have to sort them yourself.
 
 =back
@@ -229,12 +366,16 @@ sorted, you'll have to sort them yourself.
 If you talk about this module in blogs, on del.icio.us or anywhere else,
 please use the C<testcompile> tag.
 
+=head1 VERSION 
+                   
+This document describes version 0.06 of L<Test::Compile>.
+
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests to
-C<bug-test-compile@rt.cpan.org>, or through the web interface at
+C<<bug-test-compile@rt.cpan.org>>, or through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -247,10 +388,12 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
 site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
+Sagar R. Shah C<< <srshah@cpan.org> >>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2007 by Marcel GrE<uuml>nauer
@@ -258,5 +401,6 @@ Copyright 2007 by Marcel GrE<uuml>nauer
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+
 =cut
 
